<?php
/**
 * Created by PhpStorm.
 * User: robin
 * Date: 9/30/15
 * Time: 7:04 PM
 */

namespace Luticate\Auth\Business;

use Illuminate\Http\Request;
use Luticate\Auth\DBO\LuticatePermissions;
use Luticate\Auth\DBO\LuticateUsersDbo;
use Luticate\Doc\Business\LuDocBusiness;
use Luticate\Utils\LuController;
use Luticate\Utils\LuRoute;

class LuticateBusiness
{
    /**
     * @var LuticateUsersDbo
     */
    private static $_currentUser;

    public static function getCurrentUser()
    {
        return self::$_currentUser;
    }

    public static function setCurrentUser($user)
    {
        self::$_currentUser = $user;
    }

    public static function setupAuth()
    {
        $route = LuRoute::getInstance();
        $route->addMiddleware('Luticate\Auth\Business\LuticateMiddleware');
    }

    /**
     * @param $prefix string
     */
    public static function setupRoutes($prefix = "/luticate")
    {
        $ns = 'Luticate\Auth\Business\\';

        $int = "[0-9]+";
        $name = "[A-Z0-9_]+";
        $bool = "true|false";

        $id = "{id:$int}";
        $group_id = "{group_id:$int}";
        $user_id = "{user_id:$int}";
        $permission_name = "{permission_name:$name}";
        $permission_value = "{permission_value:$bool}";

        $route = LuRoute::getInstance();

        LuDocBusiness::setupRoutes("$prefix/luticate/doc");

        $route->post("$prefix/users/login", "${ns}LuticateUsersBusiness", "login");
        $route->post("$prefix/users/logout", "${ns}LuticateUsersBusiness", "logout");
        $route->post("$prefix/users/$id", "${ns}LuticateUsersBusiness", "getById", LuticatePermissions::USER_GET);
        $route->post("$prefix/users", "${ns}LuticateUsersBusiness", "getAll", LuticatePermissions::USER_GET);
        $route->post("$prefix/users/add", "${ns}LuticateUsersBusiness", "add",
            array(LuticatePermissions::USER_ADD, LuticatePermissions::USER_GET));
        $route->post("$prefix/users/$user_id/del", "${ns}LuticateUsersBusiness", "del",
            array(LuticatePermissions::USER_DEL, LuticatePermissions::USER_GET));
        $route->post("$prefix/users/$user_id/edit", "${ns}LuticateUsersBusiness", "edit",
            array(LuticatePermissions::USER_EDIT, LuticatePermissions::USER_GET));
        $route->post("$prefix/users/me/edit", "${ns}LuticateUsersBusiness", "editMe",
            LuticatePermissions::USER_EDIT_ME);
        $route->post("$prefix/users/$user_id/setPassword", "${ns}LuticateUsersBusiness", "setPassword",
            array(LuticatePermissions::USER_SET_PASSWORD, LuticatePermissions::USER_GET));
        $route->post("$prefix/users/me/setPassword", "${ns}LuticateUsersBusiness", "setPasswordMe",
            LuticatePermissions::USER_SET_PASSWORD_ME);


        $route->post("$prefix/groups/$id", "${ns}LuticateGroupsBusiness", "getById", LuticatePermissions::GROUP_GET);
        $route->post("$prefix/groups", "${ns}LuticateGroupsBusiness", "getAll", LuticatePermissions::GROUP_GET);
        $route->post("$prefix/groups/add", "${ns}LuticateGroupsBusiness", "add",
            array(LuticatePermissions::GROUP_ADD, LuticatePermissions::GROUP_GET));
        $route->post("$prefix/groups/$group_id/del", "${ns}LuticateGroupsBusiness", "del",
            array(LuticatePermissions::GROUP_DEL, LuticatePermissions::GROUP_GET));
        $route->post("$prefix/groups/$group_id/edit", "${ns}LuticateGroupsBusiness", "edit",
            array(LuticatePermissions::GROUP_EDIT, LuticatePermissions::GROUP_GET));
        $route->post("$prefix/groups/$group_id/addUser/$user_id", "${ns}LuticateGroupsBusiness", "addUser",
            array(LuticatePermissions::GROUP_ADD_USER, LuticatePermissions::GROUP_GET));
        $route->post("$prefix/groups/$group_id/delUser/$user_id", "${ns}LuticateGroupsBusiness", "delUser",
            array(LuticatePermissions::GROUP_DEL_USER, LuticatePermissions::GROUP_GET));


        $route->post("$prefix/permissions/effective/$user_id/$permission_name", "${ns}LuticatePermissionsBusiness",
            "getEffectivePermission", LuticatePermissions::PERM_EFFECTIVE_GET);
        $route->post("$prefix/permissions/effective/me/$permission_name", "${ns}LuticatePermissionsBusiness",
            "getEffectivePermissionMe");

        $route->post("$prefix/permissions/$permission_name", "${ns}LuticatePermissionsBusiness", "get",
            LuticatePermissions::PERM_GET);
        $route->post("$prefix/permissions/add/$permission_name/$permission_value", "${ns}LuticatePermissionsBusiness",
            "add", array(LuticatePermissions::PERM_ADD, LuticatePermissions::PERM_GET));
        $route->post("$prefix/permissions/$permission_name/del", "${ns}LuticatePermissionsBusiness", "del",
            array(LuticatePermissions::PERM_DEL, LuticatePermissions::PERM_GET));
        $route->post("$prefix/permissions/$permission_name/edit/$permission_value", "${ns}LuticatePermissionsBusiness",
            "edit", array(LuticatePermissions::PERM_EDIT, LuticatePermissions::PERM_GET));

        $route->post("$prefix/permissions/group/$group_id/$permission_name", "${ns}LuticatePermissionsGroupsBusiness",
            "get", LuticatePermissions::PERM_GROUP_GET);
        $route->post("$prefix/permissions/group/$group_id/add/$permission_name/$permission_value",
            "${ns}LuticatePermissionsGroupsBusiness", "add", array(LuticatePermissions::PERM_GROUP_ADD,
                LuticatePermissions::PERM_GROUP_GET));
        $route->post("$prefix/permissions/group/$group_id/$permission_name/del",
            "${ns}LuticatePermissionsGroupsBusiness", "del", array(LuticatePermissions::PERM_GROUP_DEL,
                LuticatePermissions::PERM_GROUP_GET));
        $route->post("$prefix/permissions/group/$group_id/$permission_name/edit/$permission_value",
            "${ns}LuticatePermissionsGroupsBusiness", "edit", array(LuticatePermissions::PERM_GROUP_EDIT,
                LuticatePermissions::PERM_GROUP_GET));

        $route->post("$prefix/permissions/user/$user_id/$permission_name", "${ns}LuticatePermissionsUsersBusiness",
            "get", LuticatePermissions::PERM_USER_GET);
        $route->post("$prefix/permissions/user/$user_id/add/$permission_name/$permission_value",
            "${ns}LuticatePermissionsUsersBusiness", "add", array(LuticatePermissions::PERM_USER_ADD,
                LuticatePermissions::PERM_USER_GET));
        $route->post("$prefix/permissions/user/$user_id/$permission_name/del", "${ns}LuticatePermissionsUsersBusiness",
            "del", array(LuticatePermissions::PERM_USER_DEL, LuticatePermissions::PERM_USER_GET));
        $route->post("$prefix/permissions/user/$user_id/$permission_name/edit/$permission_value",
            "${ns}LuticatePermissionsUsersBusiness", "edit", array(LuticatePermissions::PERM_USER_EDIT,
                LuticatePermissions::PERM_USER_GET));
    }
}